@@ -5,8 +5,8 @@
 mod.buffer <- function(name,species=NULL,state=thermo$opt$state,logact=-3) {
   # 20071102 add or change a buffer system
   if(is.null(species)) {
-    iname <- which(name==thermo$buffer$name)
-    if(length(iname)>0) species <- thermo$buffer$species[iname]
+    iname <- which(name==thermo$buffers$name)
+    if(length(iname)>0) species <- thermo$buffers$species[iname]
     else species <- character()
   }
   ls <- length(species)
@@ -14,23 +14,23 @@ mod.buffer <- function(name,species=NULL,state=thermo$opt$state,logact=-3) {
     stop('species must be at least as long as the other arguments')
   if(length(name)!=ls) name <- rep(name,length.out=ls)
   add <- TRUE
-  if(TRUE %in% (name %in% thermo$buffer$name)) {
+  if(TRUE %in% (name %in% thermo$buffers$name)) {
     add <- FALSE
-    imod <- which(thermo$buffer$name %in% name & thermo$buffer$species %in% species)
+    imod <- which(thermo$buffers$name %in% name & thermo$buffers$species %in% species)
     if(length(imod)>0) {
       if(state[1]=='') {
-        thermo$buffer <<- thermo$buffer[-imod,]
+        thermo$buffers <<- thermo$buffers[-imod,]
         cat(paste('mod.buffer: removed ',c2s(species),' in ',
           c2s(unique(name)),' buffer.\n',sep=''))
       } else {
-        if(missing(state)) state <- thermo$buffer$state[imod]
-        if(missing(logact)) logact <- thermo$buffer$logact[imod]
+        if(missing(state)) state <- thermo$buffers$state[imod]
+        if(missing(logact)) logact <- thermo$buffers$logact[imod]
         if(length(state)!=ls) state <- rep(state,length.out=ls)
         if(length(logact)!=ls) logact <- rep(logact,length.out=ls)
-        state.old <- thermo$buffer$state[imod]
-        logact.old <- thermo$buffer$logact[imod]
-        thermo$buffer$state[imod] <<- state
-        thermo$buffer$logact[imod] <<- logact
+        state.old <- thermo$buffers$state[imod]
+        logact.old <- thermo$buffers$logact[imod]
+        thermo$buffers$state[imod] <<- state
+        thermo$buffers$logact[imod] <<- logact
         if(identical(state.old,state) & identical(logact.old,logact)) {
           cat(paste('mod.buffer: nothing changed for ',
             c2s(species),' in ',c2s(unique(name)),' buffer.\n',sep=''))
@@ -46,13 +46,14 @@ mod.buffer <- function(name,species=NULL,state=thermo$opt$state,logact=-3) {
   if(add) {
     if(state[1]=='') state <- rep(thermo$opt$state,length.out=ls)
     t <- data.frame(name=name,species=species,state=state,logact=logact)
-    thermo$buffer <<- rbind(thermo$buffer,t)
+    thermo$buffers <<- rbind(thermo$buffers,t)
     cat(paste('mod.buffer: added ',c2s(unique(name)),'.\n',sep=''))
   }
-  return(invisible(thermo$buffer[thermo$buffer$name %in% name,]))
+  return(invisible(thermo$buffers[thermo$buffers$name %in% name,]))
 }
 
 buffer <- function(logK=NULL,ibasis=NULL,logact.basis=NULL,is.buffer=NULL,balance='PBB') {
+logK <<- logK
   # if logK is NULL load the buffer species
   # otherwise perform buffer calculations.
   if(is.null(logK)) {
@@ -63,16 +64,16 @@ buffer <- function(logK=NULL,ibasis=NULL,logact.basis=NULL,is.buffer=NULL,balanc
       ibasis <- which(thermo$basis$logact==buffers[k])
       ispecies <- numeric()
       for(i in 1:length(ibasis)) {
-        ib <- as.character(thermo$buffer$name)==as.character(thermo$basis$logact[ibasis[i]])
-        species <- as.character(thermo$buffer$species)[ib]
-        state <- as.character(thermo$buffer$state)[ib]
+        ib <- as.character(thermo$buffers$name)==as.character(thermo$basis$logact[ibasis[i]])
+        species <- as.character(thermo$buffers$species)[ib]
+        state <- as.character(thermo$buffers$state)[ib]
         #ibuff <- info(species,state,quiet=TRUE)
         #ispecies <- c(ispecies,species(ibuff))
         ispecies <- c(ispecies,species(species,state,quiet=TRUE))
       }
       ispecies.new <- c(ispecies.new,list(ispecies))
       # make sure to set the activities
-      species(ispecies,thermo$buffer$logact[ib],quiet=TRUE)
+      species(ispecies,thermo$buffers$logact[ib],quiet=TRUE)
     }
     names(ispecies.new) <- buffers
     return(ispecies.new)
